# History

## 0.0.2 - 2023-05-09

SigPro integration for processing signals

* Integrating SigPro - [Issue #7](https://github.com/signals-dev/Zephyr/issues/7) by @frances-h @sarahmish 
* Add options to xgb pipeline - [Issue #5](https://github.com/signals-dev/Zephyr/issues/5) by @sarahmish


## 0.0.1 - 2023-03-02

New modeling module using Zephyr class

* Expand GH action tests - [Issue #4](https://github.com/signals-dev/Zephyr/issues/4) by @sarahmish 
* Add XGB Pipeline - [Issue #1](https://github.com/signals-dev/Zephyr/issues/1) by @sarahmish


## 0.0.0 - 2022-11-17

First full release

* Prediction Engineering Framework by @frances-h 
* EntitySet creation by @frances-h 
* DataLabeler and initial labeling functions by @frances-h 
